==> material-ui-shell-2.0.3.tgz: package/es/components/Scrollbar/Scrollbar.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useCallback } from 'react';
import { Scrollbars } from 'react-custom-scrollbars';
import { useTheme as useAppTheme } from 'material-ui-shell/lib/providers/Theme';

var Scrollbar = function Scrollbar(props) {
  var _props$forwardedRef = props.forwardedRef,
      forwardedRef = _props$forwardedRef === void 0 ? function () {} : _props$forwardedRef,
      rest = _objectWithoutPropertiesLoose(props, ["forwardedRef"]);

  var _useAppTheme = useAppTheme(),
      isRTL = _useAppTheme.isRTL;

  var refSetter = useCallback(function (scrollbarsRef) {
    if (scrollbarsRef) {
      forwardedRef(scrollbarsRef.view);
    } else {
      forwardedRef(null);
    }
  }, [forwardedRef]);
  return (
    /*#__PURE__*/

    /* native scrollbars needs to be conditionally turned off in rtl */
    React.createElement(Scrollbars, _extends({
      hideTracksWhenNotNeeded: true,
      ref: refSetter,
      renderView: function renderView(props) {
        return isRTL ? /*#__PURE__*/React.createElement("div", _extends({}, props, {
          style: _extends(_extends({}, props.style), {}, {
            marginLeft: props.style.marginRight,
            marginRight: 0
          })
        })) : /*#__PURE__*/React.createElement("div", _extends({}, props, {
          style: _extends({}, props.style)
        }));
      }
    }, rest))
  );
};

export default Scrollbar;

==> material-ui-shell-2.0.8.tgz: package/es/components/Scrollbar/Scrollbar.js <==
var _excluded = ["forwardedRef"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useCallback } from 'react';
import { Scrollbars } from 'react-custom-scrollbars';
import { useTheme as useAppTheme } from 'material-ui-shell/lib/providers/Theme';

var Scrollbar = function Scrollbar(props) {
  var _props$forwardedRef = props.forwardedRef,
      forwardedRef = _props$forwardedRef === void 0 ? function () {} : _props$forwardedRef,
      rest = _objectWithoutPropertiesLoose(props, _excluded);

  var _useAppTheme = useAppTheme(),
      isRTL = _useAppTheme.isRTL;

  var refSetter = useCallback(function (scrollbarsRef) {
    if (scrollbarsRef) {
      forwardedRef(scrollbarsRef.view);
    } else {
      forwardedRef(null);
    }
  }, [forwardedRef]);
  return (
    /*#__PURE__*/

    /* native scrollbars needs to be conditionally turned off in rtl */
    React.createElement(Scrollbars, _extends({
      hideTracksWhenNotNeeded: true,
      ref: refSetter,
      renderView: function renderView(props) {
        return isRTL ? /*#__PURE__*/React.createElement("div", _extends({}, props, {
          style: _extends({}, props.style, {
            marginLeft: props.style.marginRight,
            marginRight: 0
          })
        })) : /*#__PURE__*/React.createElement("div", _extends({}, props, {
          style: _extends({}, props.style)
        }));
      }
    }, rest))
  );
};

export default Scrollbar;
